@@ -9,6 +9,7 @@ from typing import List
 
 import requests
 from cpg_utils.config import read_configs
+from cpg_utils.cloud import get_google_identity_token
 from analysis_runner.constants import get_server_endpoint
 from analysis_runner.git import (
     get_git_default_remote,
@@ -22,7 +23,6 @@ from analysis_runner.util import (
     _perform_version_check,
     confirm_choice,
     logger,
-    get_google_identity_token,
 )
 
 
@@ -57,6 +57,14 @@ def add_analysis_runner_args(parser=None) -> argparse.ArgumentParser:
         ),
     )
 
+    parser.add_argument(
+        '--preemptible',
+        required=False,
+        action=argparse.BooleanOptionalAction,
+        default=True,
+        help='Whether to use a preemptible machine or not.',
+    )
+
     parser.add_argument(
         '-e',
         '--env',
@@ -99,6 +107,7 @@ def run_analysis_runner(  # pylint: disable=too-many-arguments
     image=None,
     cpu=None,
     memory=None,
+    preemptible=None,
     config: List[str] = None,
     env: List[str] = None,
     use_test_server=False,
@@ -189,14 +198,15 @@ def run_analysis_runner(  # pylint: disable=too-many-arguments
 
     _config = None
     if config:
-        _config = read_configs(config)
+        _config = dict(read_configs(config))
 
-    _token = get_google_identity_token()
+    server_endpoint = get_server_endpoint(is_test=use_test_server)
+    _token = get_google_identity_token(server_endpoint)
 
     logger.info(f'Submitting {_repository}@{_commit_ref} for dataset "{dataset}"')
 
     response = requests.post(
-        get_server_endpoint(is_test=use_test_server),
+        server_endpoint,
         json={
             'dataset': dataset,
             'output': output_dir,
@@ -209,6 +219,7 @@ def run_analysis_runner(  # pylint: disable=too-many-arguments
             'image': image,
             'cpu': cpu,
             'memory': memory,
+            'preemptible': preemptible,
             'environmentVariables': _env,
             'config': _config,
         },
